@@ -193,9 +193,6 @@ add_tab_bindings (GtkBindingSet    *binding_set,
   	gtk_binding_entry_add_signal (binding_set, GDK_KP_Tab, modifiers,
 				      "tab_move", 1,
 				      G_TYPE_BOOLEAN, next);
-  	gtk_binding_entry_add_signal (binding_set, GDK_ISO_Left_Tab, modifiers,
-				      "tab_move", 1,
-				      G_TYPE_BOOLEAN, next);
 }
 
 static void
@@ -259,7 +256,6 @@ remove_tab_bindings (GtkBindingSet    *binding_set,
 {
 	gtk_binding_entry_clear (binding_set, GDK_Tab, modifiers);
   	gtk_binding_entry_clear (binding_set, GDK_KP_Tab, modifiers);
-  	gtk_binding_entry_clear (binding_set, GDK_ISO_Left_Tab, modifiers);
 }
 
 static void
@@ -713,15 +709,15 @@ allocate_dirty_child(gpointer data)
 		}
 		ad->cells = chreq.width; 
 		challoc.x = ad->pos;
-		challoc.y = (GTK_WIDGET(panel)->allocation.height -
-			     challoc.height) / 2;
+		challoc.y = GTK_WIDGET(panel)->allocation.height / 2 -
+			     challoc.height / 2;
 	} else {
 		if (ad->expand_minor) {
 			challoc.width = GTK_WIDGET (panel)->allocation.width;
 		}
 		ad->cells = chreq.height;
-		challoc.x = (GTK_WIDGET(panel)->allocation.width -
-			     challoc.width) / 2;
+		challoc.x = GTK_WIDGET(panel)->allocation.width / 2 -
+			    challoc.width / 2;
 		challoc.y = ad->pos;
 	}
 
@@ -1309,13 +1305,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				}
 				ad->cells = chreq.width;
 				challoc.x = ad->pos;
-				challoc.y = (allocation->height - challoc.height) / 2;
+				challoc.y = allocation->height / 2 - challoc.height / 2;
 			} else {
 				if (ad->expand_minor) {
 					challoc.width = allocation->width;
 				}
 				ad->cells = chreq.height;
-				challoc.x = (allocation->width - challoc.width) / 2;
+				challoc.x = allocation->width / 2 - challoc.width / 2;
 				challoc.y = ad->pos;
 			}
 			ad->min_cells  = ad->cells;
@@ -1389,13 +1385,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 					challoc.height = allocation->height;
 				}
 				challoc.x = ad->pos;
-				challoc.y = (allocation->height - challoc.height) / 2;
+				challoc.y = allocation->height / 2 - challoc.height / 2;
 			} else {
 				challoc.height = ad->cells;
 				if (ad->expand_minor) {
 					challoc.width = allocation->width;
 				}
-				challoc.x = (allocation->width - challoc.width) / 2;
+				challoc.x = allocation->width / 2 - challoc.width / 2;
 				challoc.y = ad->pos;
 			}
 			ad->dirty = FALSE;
@@ -1698,6 +1694,9 @@ panel_widget_finalize (GObject *obj)
 	g_free (panel->unique_id);
 	panel->unique_id = NULL;
 
+	if (panel->key_event)
+		gdk_event_free ((GdkEvent *)panel->key_event);
+
 	if (G_OBJECT_CLASS (panel_widget_parent_class)->finalize)
 		G_OBJECT_CLASS (panel_widget_parent_class)->finalize (obj);
 }
@@ -2931,7 +2930,9 @@ panel_widget_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
 static gboolean
 panel_widget_focus_out_event (GtkWidget *widget, GdkEventFocus *event)
 {
-	if (GTK_WINDOW (PANEL_WIDGET (widget)->panel_parent)->has_focus)
+	PanelWidget *panel_widget = PANEL_WIDGET (widget);
+
+	if (GTK_WINDOW (panel_widget->panel_parent)->has_focus)
 		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 
 	GTK_WIDGET_CLASS (panel_widget_parent_class)->focus_out_event (widget, event);
@@ -2943,9 +2944,22 @@ static gboolean
 panel_widget_real_focus (GtkWidget        *widget,
                          GtkDirectionType  direction)
 {
-	if (GTK_WIDGET_HAS_FOCUS (widget))
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+	PanelWidget *panel = PANEL_WIDGET (widget);
 
+	if (panel->key_event) {
+		if (panel->key_event->state & GDK_CONTROL_MASK) {
+			/*
+	 		 * Ctrl+Tab was pressed when focus was in applet in
+			 * another process
+			 */
+			panel_widget_focus (PANEL_WIDGET (widget));
+			return TRUE;
+		}
+	}
+
+	if (GTK_WIDGET_HAS_FOCUS (widget)) {
+		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+	}
 	return GTK_WIDGET_CLASS (panel_widget_parent_class)->focus (widget, direction);
 }
 
@@ -2975,3 +2989,14 @@ panel_widget_get_applet_orient (PanelWidget *panel)
 
 	return basep_widget_get_applet_orient (BASEP_WIDGET (panel->panel_parent));
 }
+
+void 
+panel_widget_save_key_event (PanelWidget *panel,
+			     GdkEventKey *key_event)
+{
+	if (panel->key_event) {
+		gdk_event_free ((GdkEvent *)panel->key_event);
+	}
+	panel->key_event = (GdkEventKey *) gdk_event_copy ((GdkEvent *)key_event);
+}
+
